Module config

Module config 

Configuration management for Plex.

Provides structures and functions to parse the plex.toml configuration file and convert it into boot targets that the application can execute.

Structs

Config
Top-level configuration structure

Enums

ConfigError
Errors that can occur when loading or parsing the configuration.
TargetConfig
Represents a boot target configuration entry in plex.toml.