Module app

Module app 

Structs

AppCtx
Borrowed UI and system resources for a running app.

Enums

AppResult
Outcome for a blocking app run.

Traits

App
Blocking app entry point.
DisplayEntry
A trait that defines an App that can be drawn as an entry in the boot menu.