pub enum AppResult {
Done,
Booted,
Yield,
Error(AppError),
}Expand description
Outcome for a blocking app run.
Variants
Done
App finished and returned control to the caller.
Booted
App initiated a boot flow and should not return to the caller.
Yield
Yield control back to the runner, indicates an App has not finished execution. This may be used to trigger a redraw from the runner.
Error(AppError)
App encountered an unrecoverable error during execution.