DisplayEntry

Trait DisplayEntry 

pub trait DisplayEntry {
    // Required method
    fn display_options(&self) -> DisplayOptions;
}
A trait that defines an App that can be drawn as an entry in the boot menu.

Required Methods

fn display_options(&self) -> DisplayOptions

Returns the options used to display this entry on the screen.

Implementors