Module bootables

Module bootables 

Abstractions for different types of boot targets.

Provides the generic definitions for boot targets (e.g., standard EFI executables and ISO images) and how they are displayed and executed within the application.

Structs

DisplayOptions
Options for rendering a boot entry in the user interface.
GenericBootTarget
A generic EFI executable + cmd chain-loadable target.

Enums

BootTarget
Represents any bootable target that can be executed by the bootloader.