Module implementing embedded_graphics_core::DrawTarget for the Rust UEFI crate. It is actually just a buffer, and the push to uefi is done via blit during flush().
Structs
- GopDisplay
- An
embedded-graphicsdraw target using the UEFI Graphics Output Protocol (Gop).