GopDisplay

Struct GopDisplay 

pub struct GopDisplay<'a> { /* private fields */ }
An embedded-graphics draw target using the UEFI Graphics Output Protocol (Gop).

This maintains an internal buffer where drawing operations happen. To display the drawn image, you must call flush() which blits the entire buffer to the screen.

Implementations

Source

impl<'a> GopDisplay<'a>

pub fn new(gop: &'a mut GraphicsOutput) -> Self

Create a new GopDisplay matching the current GOP mode resolution.

pub fn flush(&mut self) -> Result<(), Error>

Blit the entire buffer to the framebuffer.

pub fn clear(&mut self, color: Rgb888)

Clear the buffer to a specific color.