pub struct Partition {
pub handle: Handle,
pub gpt_partition_info: Option<GptPartitionEntry>,
pub mbr_partition_info: Option<MbrPartitionRecord>,
pub is_system: bool,
pub is_boot: bool,
pub iso_path: Option<String>,
}Expand description
Metadata about a discovered partition
Fields
handle: HandleUEFI handle for opening protocols on this partition.
gpt_partition_info: Option<GptPartitionEntry>GPT pt info, if avail.
mbr_partition_info: Option<MbrPartitionRecord>MBR pt info, if avail.
is_system: boolWhether marked as system partition (not necessarily boot partition).
is_boot: boolWhether this is the partition from which the bootloader was launched.
iso_path: Option<String>Optional path to an ISO file within this partition, if treating an ISO as a partition.