Module boot_menu

Module boot_menu 

Boot menu interface.

Renders the list of configured boot targets and handles user input to select and boot one.

Structs

BootMenu
The main boot menu interface for displaying and selecting boot targets. Very simple BootMenu that displays listings, handles keyboard input.