BootMenu

Struct BootMenu 

pub struct BootMenu<'a, T>
where T: App + DisplayEntry,
{ /* private fields */ }
The main boot menu interface for displaying and selecting boot targets. Very simple BootMenu that displays listings, handles keyboard input.

Implementations

Source

impl<'a, T: App + DisplayEntry> BootMenu<'a, T>

pub fn new(targets: &'a mut [T]) -> Self

Creates a new boot menu to manage the provided list of targets.

pub fn draw(&mut self, display: &mut GopDisplay<'_>) -> Result<(), AppError>

Draws boot options to the buff.

pub fn wait_for_selection( &mut self, ctx: &mut AppCtx<'_>, ) -> Result<usize, AppError>

Handle arrow key input and return the selected index when Enter is pressed.