Core application components, including boot targets and display management.
This module houses the fundamental structures that run the application, manage the graphics output, and handle the logic for different types of bootables.
Core application components, including boot targets and display management.
This module houses the fundamental structures that run the application, manage the graphics output, and handle the logic for different types of bootables.