Module app
plex_
boot
0.1.0
Module app
Module Items
Structs
Enums
Traits
In plex_
boot::
core
plex_boot
::
core
Module
app
Structs

AppCtx
Borrowed UI and system resources for a running app.
Enums

AppResult
Outcome for a blocking app run.
Traits

App
Blocking app entry point.
Display
Entry
A trait that defines an App that can be drawn as an entry in the boot menu.