pub trait DisplayEntry {
// Required method
fn display_options(&self) -> DisplayOptions;
}Expand description
A trait that defines an App that can be drawn as an entry in the boot menu.
Required Methods
Sourcefn display_options(&self) -> DisplayOptions
fn display_options(&self) -> DisplayOptions
Returns the options used to display this entry on the screen.