Abstractions for different types of boot targets.
Provides the generic definitions for boot targets (e.g., standard EFI executables and ISO images) and how they are displayed and executed within the application.
Structs
- Display
Options - Options for rendering a boot entry in the user interface.
- Generic
Boot Target - A generic EFI executable + cmd chain-loadable target.
Enums
- Boot
Target - Represents any bootable target that can be executed by the bootloader.