UI overlays for displaying messages and errors.
Provides reusable graphical overlays that can be drawn on top of the current screen, such as error dialogs.
Structs
- Error
Overlay - An error overlay that displays an application error and waits for the user to acknowledge it before dismissing.